# Contributing guidelines

Here is the best way to contribute:

* Fork the project
* Make your changes
* Open a pull request
* Explain why your changes should be committed to the repo

I will decided whether to allow or disallow your changes, feel free to suggest any changes you want as long as they do not significantly change the project.
